==> haskell-quickcheck-assertions-0.3.0-282-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-7YbrL8c0C83D40pKWaLNrg
key:                  quickcheck-assertions-0.3.0-7YbrL8c0C83D40pKWaLNrg
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  5a2db99f121ec24d9f8bc967ba0316e7
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-7YbrL8c0C83D40pKWaLNrg
depends:
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED base-4.16.4.0
    ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-284-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-Kdz8NlHgtjeCFVwj9OkvG7
key:                  quickcheck-assertions-0.3.0-Kdz8NlHgtjeCFVwj9OkvG7
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  b465b61494ddf86217ce4cb5986e4d02
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-Kdz8NlHgtjeCFVwj9OkvG7
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
